==> mauticGIT-Test-20251111_133203.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/c8/c829ee79e560eaaff1406f72634388e7.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/AssetBundle/Translations/en_US/messages.ini */
class __TwigTemplate_5cdb5fba1963b9e787cbb3150ba20009 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "mautic.asset.abtest.criteria=\"Asset Stats\"
mautic.asset.abtest.criteria.downloads=\"Download rate\"
mautic.asset.abtest.downloads=\"%count% downloads\"
mautic.asset.abtest.label.downloads=\"Number of downloads\"
mautic.asset.abtest.label.hits=\"Number of unique asset downloads\"
mautic.asset.abtest.label.sentemils=\"Number of sent emails\"
mautic.asset.actions=\"Asset actions\"
mautic.asset.asset=\"Asset\"
mautic.protip.assets.gating=\"Gate valuable assets behind a form to capture lead information before allowing the download.\"
mautic.protip.assets.naming=\"Use consistent naming conventions to keep assets organized\"
mautic.protip.assets.repurpose=\"Repurpose high-performing assets across different channels and campaigns\"
mautic.protip.assets.track=\"Track asset performance metrics in the dashboard widgets to identify top-performing content\"
mautic.asset.asset.searchcommand.lang=\"lang\"
mautic.asset.asset.searchcommand.lang.description=\"Filters assets by a specific language code\"
mautic.asset.asset.downloads.total=\"Total: count\"
mautic.asset.asset.downloads.unique=\"Unique: count\"
mautic.asset.asset.error.missing.remote.path=\"A remote URL must be specified when remote storage is selected.\"
mautic.asset.asset.form.confirmbatchdelete=\"Delete the selected assets?\"
mautic.asset.asset.form.confirmdelete=\"Delete the asset, %name%?\"
mautic.asset.asset.form.file.upload=\"Upload a file (max filesize allowed = %max%)\"
mautic.asset.asset.form.language.help=\"Select language of the asset.\"
mautic.asset.asset.form.remotePath=\"Remote URL\"
mautic.asset.asset.form.storageLocation=\"Storage Location\"
mautic.asset.asset.form.storageLocation.local=\"Local\"
mautic.asset.asset.form.storageLocation.remote=\"Remote\"
mautic.asset.asset.form.disallow.crawlers=\"Block search engines from indexing this file\"
mautic.asset.asset.form.disallow.crawlers.descr=\"If you don't want to index files like PDF, DOCX etc, this option will disallow search bots by using the X-Robots-Tag HTTP header.\"
mautic.asset.asset.help.alias=\"Letters and numbers (hyphens allowed) used for URL generation of this asset. A unique alias based on the title will be autogenerated if left empty.\"
mautic.asset.asset.menu.edit=\"Edit Asset\"
mautic.asset.asset.menu.new=\"New Asset\"
mautic.asset.asset.path.relative=\"Relative Path\"
mautic.asset.asset.preview=\"Preview\"
mautic.asset.asset.size=\"Filesize\"
mautic.asset.asset.submitaction.downloadfile=\"Download an asset\"
mautic.asset.asset.submitaction.downloadfile.msg=\"<br />Your download should start within 5 seconds. If it does not, <a href='%url%'>click here</a>.<script>setTimeout(function(){window.location='%url%';}, 5000);</script>\"
mautic.asset.asset.submitaction.downloadfile_descr=\"Download the selected asset upon submitting the form.\"
mautic.asset.asset.thead.download.count=\"Download count\"
mautic.asset.asset.url=\"Download URL\"
mautic.asset.assets=\"Assets\"
mautic.asset.campaign.event.assets=\"Limit to Assets\"
mautic.asset.campaign.event.assets.descr=\"Select the assets this trigger applies to. If none are selected, the event will trigger for any asset.\"
mautic.asset.campaign.event.download=\"Downloads asset\"
mautic.asset.campaign.event.download_descr=\"Trigger actions upon downloading an asset.\"
mautic.asset.config.form.allowed.extensions=\"Allowed file extensions\"
mautic.asset.config.form.allowed.extensions.tooltip=\"Comma separated list of file extensions. Only files with specified file extensions will be able to upload.\"
mautic.asset.config.form.upload.dir=\"Path to the asset directory\"
mautic.asset.config.form.upload.dir.tooltip=\"Set the absolute path to where assets should be uploaded to. %kernel.project_dir%/app can be used as a placeholder for the app directory in the public web root. It is advised to use a directory outside of the public web root to prevent assets from being accessible by the public.\"
mautic.asset.config.form.max.size=\"Maximum size (MB)\"
mautic.asset.config.form.max.size.tooltip=\"Set the maximum size of uploaded assets in MB (Megabytes). Default value is 6MB.\"
mautic.asset.downloadcount=\"Download count\"
mautic.asset.drop.file.here=\"Drop the file here or click to browse and select the file.\"
mautic.asset.error.file.failed=\"File failed to upload.\"
mautic.asset.event.download=\"Asset downloaded\"
mautic.asset.filename.local=\"Local filename\"
mautic.asset.filename.original=\"Original filename\"
mautic.asset.filename.remote=\"Remote filename\"
mautic.asset.form.submit.assets=\"Asset\"
mautic.asset.form.submit.assets_descr=\"Choose the asset to be downloaded.\"
mautic.asset.form.submit.latest.category=\"Use the latest asset from the category\"
mautic.asset.form.submit.latest.category_descr=\"If 'Use latest file from the category' Asset option is selected then the action will download the latest asset from the selected category.\"
mautic.asset.graph.line.downloads=\"Downloads\"
mautic.asset.graph.pie.statuses=\"Download HTTP statuses\"
mautic.asset.no_audio_support=\"Your browser does not support audio.\"
mautic.asset.no_video_support=\"Your browser does not support video.\"
mautic.asset.noresults.tip=\"Assets can be white papers, PDFs, images, docs, eBooks, or pretty much any electronic document that you want to distribute to customers. Want to offer an asset after a customer has submitted a form? Easy! Add the 'Download an asset' action when building the form.\"
mautic.asset.permissions.assets=\"Assets - User has access to\"
mautic.asset.permissions.header=\"Asset Permissions\"
mautic.asset.point.action.assets=\"Limit to the selected assets\"
mautic.asset.point.action.assets.descr=\"Select the assets this action applies to. If none are selected, it'll apply to any asset.\"
mautic.asset.point.action.download=\"Downloads an asset\"
mautic.asset.point.action.download_descr=\"Update the contact's points when an asset is downloaded.\"
mautic.asset.remote.file.browse=\"Browse Remote Files\"
mautic.asset.remote.no_results=\"No remote files found.\"
mautic.asset.remote.select_service=\"Select the service to the left. If none are listed, configure the Cloud Storage addon.\"
mautic.asset.report.download.code=\"Response code\"
mautic.asset.report.download.date_download=\"Date downloaded\"
mautic.asset.report.download_count=\"Download count\"
mautic.asset.report.downloads.table=\"Asset Downloads\"
mautic.asset.report.unique_download_count=\"Unique download count\"
mautic.asset.stage.action.download=\"Download asset\"
mautic.asset.table.most.downloaded=\"Most downloaded assets\"
mautic.asset.table.top.referrers=\"Top referrers\"
mautic.campaign.asset.download=\"Asset downloaded\"
mautic.config.AssetBundle.upload_dir=\"Upload Directory\"
mautic.config.tab.assetconfig=\"Asset Settings\"
mautic.asset.dashboard.widgets=\"Asset Widgets\"
mautic.asset.unique=\"Unique\"
mautic.asset.repetitive=\"Repetitive\"
mautic.widget.asset.downloads.in.time=\"Downloads in time\"
mautic.widget.unique.vs.repetitive.downloads=\"Unique vs repetitive downloads\"
mautic.widget.popular.assets=\"Popular assets\"
mautic.widget.created.assets=\"Created assets\"
mautic.report.group.assets=\"Assets\"
mautic.asset.asset.help.searchcommands=\"<strong>Search commands</strong><br />ids:ID1,ID2 (comma separated IDs, no spaces)<br />is:mine<br />is:published<br />is:unpublished<br />name:*<br />is:uncategorized<br />category:{category alias}\"
mautic.asset.asset.error.file.mimetype=\"The file type is not allowed.\"";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/AssetBundle/Translations/en_US/messages.ini";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/AssetBundle/Translations/en_US/messages.ini", "/var/www/mautic-ktn/app/bundles/AssetBundle/Translations/en_US/messages.ini");
    }
}

==> mauticGIT-Test-20260116_092227.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/c8/c829ee79e560eaaff1406f72634388e7.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/AssetBundle/Translations/en_US/messages.ini */
class __TwigTemplate_5cdb5fba1963b9e787cbb3150ba20009 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "mautic.asset.abtest.criteria=\"Asset Stats\"
mautic.asset.abtest.criteria.downloads=\"Download rate\"
mautic.asset.abtest.downloads=\"%count% downloads\"
mautic.asset.abtest.label.downloads=\"Number of downloads\"
mautic.asset.abtest.label.hits=\"Number of unique asset downloads\"
mautic.asset.abtest.label.sentemils=\"Number of sent emails\"
mautic.asset.actions=\"Asset actions\"
mautic.asset.asset=\"Asset\"
mautic.protip.assets.gating=\"Gate valuable assets behind a form to capture lead information before allowing the download.\"
mautic.protip.assets.naming=\"Use consistent naming conventions to keep assets organized\"
mautic.protip.assets.repurpose=\"Repurpose high-performing assets across different channels and campaigns\"
mautic.protip.assets.track=\"Track asset performance metrics in the dashboard widgets to identify top-performing content\"
mautic.asset.asset.searchcommand.lang=\"lang\"
mautic.asset.asset.searchcommand.lang.description=\"Filters assets by a specific language code\"
mautic.asset.asset.downloads.total=\"Total: count\"
mautic.asset.asset.downloads.unique=\"Unique: count\"
mautic.asset.asset.error.missing.remote.path=\"A remote URL must be specified when remote storage is selected.\"
mautic.asset.asset.form.confirmbatchdelete=\"Delete the selected assets?\"
mautic.asset.asset.form.confirmdelete=\"Delete the asset, %name%?\"
mautic.asset.asset.form.file.upload=\"Upload a file (max filesize allowed = %max%)\"
mautic.asset.asset.form.language.help=\"Select language of the asset.\"
mautic.asset.asset.form.remotePath=\"Remote URL\"
mautic.asset.asset.form.storageLocation=\"Storage Location\"
mautic.asset.asset.form.storageLocation.local=\"Local\"
mautic.asset.asset.form.storageLocation.remote=\"Remote\"
mautic.asset.asset.form.disallow.crawlers=\"Block search engines from indexing this file\"
mautic.asset.asset.form.disallow.crawlers.descr=\"If you don't want to index files like PDF, DOCX etc, this option will disallow search bots by using the X-Robots-Tag HTTP header.\"
mautic.asset.asset.help.alias=\"Letters and numbers (hyphens allowed) used for URL generation of this asset. A unique alias based on the title will be autogenerated if left empty.\"
mautic.asset.asset.menu.edit=\"Edit Asset\"
mautic.asset.asset.menu.new=\"New Asset\"
mautic.asset.asset.path.relative=\"Relative Path\"
mautic.asset.asset.preview=\"Preview\"
mautic.asset.asset.size=\"Filesize\"
mautic.asset.asset.submitaction.downloadfile=\"Download an asset\"
mautic.asset.asset.submitaction.downloadfile.msg=\"<br />Your download should start within 5 seconds. If it does not, <a href='%url%'>click here</a>.<script>setTimeout(function(){window.location='%url%';}, 5000);</script>\"
mautic.asset.asset.submitaction.downloadfile_descr=\"Download the selected asset upon submitting the form.\"
mautic.asset.asset.thead.download.count=\"Download count\"
mautic.asset.asset.url=\"Download URL\"
mautic.asset.assets=\"Assets\"
mautic.asset.campaign.event.assets=\"Limit to Assets\"
mautic.asset.campaign.event.assets.descr=\"Select the assets this trigger applies to. If none are selected, the event will trigger for any asset.\"
mautic.asset.campaign.event.download=\"Downloads asset\"
mautic.asset.campaign.event.download_descr=\"Trigger actions upon downloading an asset.\"
mautic.asset.config.form.allowed.extensions=\"Allowed file extensions\"
mautic.asset.config.form.allowed.extensions.tooltip=\"Comma separated list of file extensions. Only files with specified file extensions will be able to upload.\"
mautic.asset.config.form.upload.dir=\"Path to the asset directory\"
mautic.asset.config.form.upload.dir.tooltip=\"Set the absolute path to where assets should be uploaded to. %kernel.project_dir%/app can be used as a placeholder for the app directory in the public web root. It is advised to use a directory outside of the public web root to prevent assets from being accessible by the public.\"
mautic.asset.config.form.max.size=\"Maximum size (MB)\"
mautic.asset.config.form.max.size.tooltip=\"Set the maximum size of uploaded assets in MB (Megabytes). Default value is 6MB.\"
mautic.asset.downloadcount=\"Download count\"
mautic.asset.drop.file.here=\"Drop the file here or click to browse and select the file.\"
mautic.asset.error.file.failed=\"File failed to upload.\"
mautic.asset.event.download=\"Asset downloaded\"
mautic.asset.filename.local=\"Local filename\"
mautic.asset.filename.original=\"Original filename\"
mautic.asset.filename.remote=\"Remote filename\"
mautic.asset.form.submit.assets=\"Asset\"
mautic.asset.form.submit.assets_descr=\"Choose the asset to be downloaded.\"
mautic.asset.form.submit.latest.category=\"Use the latest asset from the category\"
mautic.asset.form.submit.latest.category_descr=\"If 'Use latest file from the category' Asset option is selected then the action will download the latest asset from the selected category.\"
mautic.asset.graph.line.downloads=\"Downloads\"
mautic.asset.graph.pie.statuses=\"Download HTTP statuses\"
mautic.asset.no_audio_support=\"Your browser does not support audio.\"
mautic.asset.no_video_support=\"Your browser does not support video.\"
mautic.asset.noresults.tip=\"Assets can be white papers, PDFs, images, docs, eBooks, or pretty much any electronic document that you want to distribute to customers. Want to offer an asset after a customer has submitted a form? Easy! Add the 'Download an asset' action when building the form.\"
mautic.asset.permissions.assets=\"Assets - User has access to\"
mautic.asset.permissions.header=\"Asset Permissions\"
mautic.asset.point.action.assets=\"Limit to the selected assets\"
mautic.asset.point.action.assets.descr=\"Select the assets this action applies to. If none are selected, it'll apply to any asset.\"
mautic.asset.point.action.download=\"Downloads an asset\"
mautic.asset.point.action.download_descr=\"Update the contact's points when an asset is downloaded.\"
mautic.asset.remote.file.browse=\"Browse Remote Files\"
mautic.asset.remote.no_results=\"No remote files found.\"
mautic.asset.remote.select_service=\"Select the service to the left. If none are listed, configure the Cloud Storage addon.\"
mautic.asset.report.download.code=\"Response code\"
mautic.asset.report.download.date_download=\"Date downloaded\"
mautic.asset.report.download_count=\"Download count\"
mautic.asset.report.downloads.table=\"Asset Downloads\"
mautic.asset.report.unique_download_count=\"Unique download count\"
mautic.asset.stage.action.download=\"Download asset\"
mautic.asset.table.most.downloaded=\"Most downloaded assets\"
mautic.asset.table.top.referrers=\"Top referrers\"
mautic.campaign.asset.download=\"Asset downloaded\"
mautic.config.AssetBundle.upload_dir=\"Upload Directory\"
mautic.config.tab.assetconfig=\"Asset Settings\"
mautic.asset.dashboard.widgets=\"Asset Widgets\"
mautic.asset.unique=\"Unique\"
mautic.asset.repetitive=\"Repetitive\"
mautic.widget.asset.downloads.in.time=\"Downloads in time\"
mautic.widget.unique.vs.repetitive.downloads=\"Unique vs repetitive downloads\"
mautic.widget.popular.assets=\"Popular assets\"
mautic.widget.created.assets=\"Created assets\"
mautic.report.group.assets=\"Assets\"
mautic.asset.asset.help.searchcommands=\"<strong>Search commands</strong><br />ids:ID1,ID2 (comma separated IDs, no spaces)<br />is:mine<br />is:published<br />is:unpublished<br />name:*<br />is:uncategorized<br />category:{category alias}\"
mautic.asset.asset.error.file.mimetype=\"The file type is not allowed.\"";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/AssetBundle/Translations/en_US/messages.ini";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/AssetBundle/Translations/en_US/messages.ini", "/var/www/html/mauticGIT-Test/app/bundles/AssetBundle/Translations/en_US/messages.ini");
    }
}
